@@ -217,12 +217,13 @@ class MultiLayerShortCutLSTM(_ShortCutLSTMBaseNeuralNet):
         self.num_classes = num_classes
         self.num_layers = num_layers
         self.input_size = input_size
+        self.shortcut_size = X_shortcut.shape[1]
         self.hidden_size = hidden_size
 
         self.lstm = nn.LSTM(input_size=input_size, hidden_size=hidden_size,
                             num_layers=num_layers, batch_first=True)
 
-        self.fc = nn.Linear(hidden_size, num_classes)
+        self.fc = nn.Linear(hidden_size+self.shortcut_size, num_classes)
         # Set activation functions
         if activation is None:
             self.activation = lambda x: x
@@ -248,6 +249,9 @@ class MultiLayerShortCutLSTM(_ShortCutLSTMBaseNeuralNet):
         h_out = h_out.view(-1, self.hidden_size)
         #print(h_out.shape)
         out = self.fc(h_out)
+
+        x = torch.cat([out, x_shortcut], dim=1)
+
         #print(out.shape)
         out = self.activation(out)
         if self.num_layers>1:
