@@ -17,7 +17,7 @@ import torch
 import torch.nn as nn
 
 class AbstractRunner(ABC):
-    def __init__(self, starting_date = None, running_date = None, drop_token=None, dropbox_backup = True, supervision_npy_file_suffix='_supervision.npy', macro_supervision_npy_file_suffix='_macro_supervision.npy', features_saving_suffix='_features.npy', features_names_saving_suffix='_features_names.npy', returns_pkl_file_name='returns.pkl', local_root_directory='../data/', user = 'napoleon', n_start = 252, maximum_precision=True):
+    def __init__(self, starting_date = None, running_date = None, drop_token=None, dropbox_backup = True, supervision_npy_file_suffix='_supervision.npy', macro_supervision_npy_file_suffix='_macro_supervision.npy', features_saving_suffix='_features.npy', features_names_saving_suffix='_features_names.npy', returns_pkl_file_name='returns.pkl', shortcut_features_pkl_file_name = 'shortcut.pkl', local_root_directory='../data/', user = 'napoleon', n_start = 252, maximum_precision=True, shortcut_features=False):
         super().__init__()
         self.supervision_npy_file_suffix=supervision_npy_file_suffix
         self.macro_supervision_npy_file_suffix=macro_supervision_npy_file_suffix
@@ -25,6 +25,8 @@ class AbstractRunner(ABC):
         self.features_names_saving_suffix=features_names_saving_suffix
         self.returns_pkl_file_name=returns_pkl_file_name
         self.local_root_directory=local_root_directory
+        self.shortcut_features_pkl_file_name = shortcut_features_pkl_file_name
+        self.shortcut_features = shortcut_features
         self.user=user
         self.n_start = n_start
         self.dropbox_backup = dropbox_backup
@@ -106,7 +108,8 @@ class SimpleExplainer(AbstractRunner):
                                                                                          local_root_directory=self.local_root_directory,
                                                                                          user=self.user,
                                                                                          features_saving_suffix=self.features_saving_suffix,
-                                                                                         features_names_saving_suffix=self.features_names_saving_suffix)
+                                                                                         features_names_saving_suffix=self.features_names_saving_suffix,
+                                                                                         shortcut_features_pkl_file_name=self.shortcut_features_pkl_file_name)
 
         features = features[:len(df)]
         result = result[:len(df)]
